#ifndef NT2_INCLUDE_FUNCTIONS_MULTIPLIES_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MULTIPLIES_HPP_INCLUDED

#include <nt2/operator/include/functions/multiplies.hpp>

#endif
